#!/bin/bash
Summary:	GL Utility Toolkit (GLUT)
Name:		glut
Version:	3.7
Release: 12
License:	Freely Redistributable
Group:		System Environment/Libraries
Source0:	http://www.opengl.org/developers/documentation/glut/%{name}-%{version}.tar.gz
Source1:	http://www.opengl.org/developers/documentation/glut/%{name}-3.spec.ps.gz
Patch0:		%{name}-examples-paths.patch
Patch1:		%{name}-link.patch
URL:		http://www.opengl.org/developers/documentation/glut.html
Buildroot:	%{_tmppath}/%{name}-%{version}-root
# Xlib is required
BuildRequires:  XFree86-devel, perl
# This needs to link to libGL, however we do not want to force a specific
# implementation of libGL to be present, such as Mesa, so we BuildRequires
# the libGL.so instead, and do so in the officially standardized location
# of /usr/lib/libGL.so (OpenGL ABI on Linux Specification), and on x86_64
# and ppc64 it is /usr/lib64/libGL.so
BuildRequires:	%{_libdir}/libGL.so

%description
GL Utility Toolkit (GLUT) is a 3-D graphics library which uses the
OpenGL API.

%package devel
Summary:	GLUT Development environment
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Libraries and header files required for GLUT development.

%prep
%setup -q
%patch0 -p1
#%patch1 -p1

install %{SOURCE1} .

%build
# Fixup for lib64 on AMD Hammer and ppc64
perl -p -i -e 's#/usr/X11R6/lib#/usr/X11R6/%{_lib}#g' linux/Makefile

rm -f Glut.cf
cp -f linux/Glut.cf .
./mkmkfiles.imake
cd lib/glut
rm -f Makefile
cp -f ../../linux/Makefile .
%{__make} depend
%{__make} "BOOTSTRAPCFLAGS=$RPM_OPT_FLAGS -fPIC" \
          "CDEBUGFLAGS=" "CCOPTIONS=$RPM_OPT_FLAGS -fPIC" \
          "CXXDEBUGFLAGS=" "CXXOPTIONS=$RPM_OPT_FLAGS -fPIC"

# make libglsmap.a
(
    cd ../glsmap
    %{__make} "BOOTSTRAPCFLAGS=$RPM_OPT_FLAGS" \
	          "CDEBUGFLAGS=" "CCOPTIONS=$RPM_OPT_FLAGS" \
	          "CXXDEBUGFLAGS=" "CXXOPTIONS=$RPM_OPT_FLAGS"
)

# make libmui.a
(
    cd ../mui
    %{__make} "BOOTSTRAPCFLAGS=$RPM_OPT_FLAGS" \
	          "CDEBUGFLAGS=" "CCOPTIONS=$RPM_OPT_FLAGS" \
	          "CXXDEBUGFLAGS=" "CXXOPTIONS=$RPM_OPT_FLAGS"
)

# prepare to make manuals
(
    cd ../../man
	sed s/gle// Imakefile > Imakefile.tmp
	mv -f Imakefile.tmp Imakefile
	xmkmf
)

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_libdir},%{_mandir}/man3,%{_includedir}} \
	$RPM_BUILD_ROOT

install lib/glut/libglut.so.*.* $RPM_BUILD_ROOT%{_libdir}
ln -sf libglut.so.3 $RPM_BUILD_ROOT%{_libdir}/libglut.so

install lib/*/lib*.a $RPM_BUILD_ROOT%{_libdir}

rm -f include/GL/tube.h
cp -rp include/* $RPM_BUILD_ROOT%{_includedir}

make -C man DESTDIR=$RPM_BUILD_ROOT MANDIR=%{_mandir}/man3 install.man

/sbin/ldconfig -n $RPM_BUILD_ROOT/%{_libdir}

# Installing examples...
#(
#    cd progs
#    find . -name Makefile.win -o -name Makefile.sgi -o -name Makefile.bak | xargs rm -f
#    cp -rp * $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
#)

%clean
rm -rf $RPM_BUILD_ROOT

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/lib*.so.*

%files devel
%defattr(644,root,root,755)
%doc NOTICE CHANGES FAQ.glut README*
%{_includedir}/GL/*.h
%{_includedir}/mui
%{_libdir}/lib*.a
%{_libdir}/lib*.so
%{_mandir}/man3/*

#%files examples
#%defattr(644,root,root,755)
#%{_examplesdir}/%{name}-%{version}

%changelog
* Tue Feb 04 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- add symlinks to shared libs

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Sat Nov 23 2002 Mike A. Harris <mharris@redhat.com> 3.7-10
- Added perl one liner to fix lib64 issue, and a buildrequires on perl

* Mon Nov 18 2002 Mike A. Harris <mharris@redhat.com> 3.7-9
- Removed "Requires: /usr/lib/libGL.so.1" from main package, and removed
  "Requires: /usr/lib/libGL.so.1" and "/usr/lib/libGL.so" from devel package
  as they are fairly bogus (#77949)
- Fixed BuildRequires to use _libdir to fix a /usr/lib -> /usr/lib64 issue
  on x86_64 (AMD Hammer)
- Added BuildRequires: XFree86-devel
- Commented all BuildRequires so other developers aren not confused.

* Fri Aug  9 2002 Mike A. Harris <mharris@redhat.com> 3.7-8
- Updated URL and Source tags with new URLs (#71118)
- Changed Requires/Buildrequires to use explicit library instead of Mesa and
  Mesa-devel packages.

* Fri Jun 21 2002 Tim Powers <timp@redhat.com> 3.7-7
- automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com> 3.7-6
- automated rebuild

* Tue May 21 2002 Mike A. Harris <mharris@redhat.com> 3.7-5
- Rebuilt in new environment

* Mon Feb 26 2002 Mike A. Harris <mharris@redhat.com> 3.7-4
- Rebuilt in new environment

* Sun Feb 03 2002 Mike A. Harris <mharris@redhat.com> 3.7-3
- Fixed some breakage in the install section

* Wed Jan 09 2002 Tim Powers <timp@redhat.com> 3.7-2
- automated rebuild

* Tue Dec 26 2001 Mike A. Harris <mharris@redhat.com> 3.7-1
- Initial packaging

